# coding: utf-8
# create by tongshiwei on 2019-9-4

from .ecli import cli as ecli
from .module import Module
from .service import CliServiceModule, service_wrapper
